Baseline Hazard Step-Function
bas_hazard.RdThe method computes the baseline hazard step-function in each interval of the time-domain, using the estimated parameters \(\phi_k, \forall k\)
Value
Numerical vector of length equal to the number of intervals of the time-domain, with the value of the baseline hazard step-function.
Examples
# Consider the 'Academic Dropout dataset'
data(data_dropout)
# Define the variables needed for the model execution
formula <- time_to_event ~ Gender + CFUP + cluster(group)
time_axis <- c(1.0, 1.4, 1.8, 2.3, 3.1, 3.8, 4.3, 5.0, 5.5, 5.8, 6.0)
eps <- 1e-10
categories_range_min <- c(-8, -2, eps, eps, eps)
categories_range_max <- c(-eps, 0, 1 - eps, 1, 10)
# \donttest{
# Call the main model
result <- AdPaikModel(formula, data_dropout, time_axis,
categories_range_min, categories_range_max)
bas_hazard(result)
#> [1] 0.24904054 0.15791778 0.66096430 0.04742117 0.12241651 0.35313323
#> [7] 0.03181691 0.30586064 0.03907797 0.09806931
# }