Learn R Programming

TimeDepFrail (version 0.1.0)

check.centre: Check Correctness for the Cluster Variable

Description

The function controls that the provided cluster variable is a vector, with at least two levels. Indeed, it is not possible to apply the Time-Dependent Shared Frailty Cox Model with no clusters.

Usage

check.centre(centre)

Value

An error if any condition is not satisfied.

Arguments

centre

Numerical vector of length equal to the number of individuals in the study, containing the individual grouo/cluster membership.