Learn R Programming

TimeDepFrail (version 0.1.0)

check.frailty_dispersion: Check Correctness of Frailty Standard Deviation

Description

The function controls that the frailty standard deviation vector has a length equal to the number of inyervals of the time domain and that its elements are non-negative.

Usage

check.frailty_dispersion(frailty_dispersion, n_intervals)

Value

An error if any condition is not satisfied.

Arguments

frailty_dispersion

Frailty dispersion

n_intervals

Number of intervals of the time-domain