Learn R Programming

TimeDepFrail (version 0.1.0)

check.pos_frailty_sd: Check Positivity of the Frailty Standard Deviation

Description

The method controls that the frailty standard deviation vector has non-negative elements

Usage

check.pos_frailty_sd(sd, n_intervals)

Value

An error if any condition is not satisfied.

Arguments

sd

Numerical vector of length equal to the number of intervals, containing the frailty standard deviation

n_intervals

Number of intervals of the time-domain