The function controls that the structure of the 'Posterior Frailty Estimates' coincides with the theoretical one.
check.structure_post_frailty_est(post_frailty_est, n_intervals, n_centres)An error if any condition is not satisfied.
Posterior frailty estimates S3 object of class 'PFE.AdPaik', composed of three elements:
'alpha': posterior frailty estimates for \(\alpha_j, \forall j\). It is a vector of length equal to the number of centres.
'eps': posterior frailty estimates for \(\epsilon_{jk}, \forall j,k\). It is a matrix of dimension (n_centres, n_intervals).
'Z': posterior frailty estimates for \(Z_{jk} = \alpha_j + \epsilon_{jk}, \forall j,k\). It is a matrix of dimension (n_centres, n_intervals)
Number of intervals of the time-domain
Number of centres/clusters.