Learn R Programming

TimeDepFrail (version 0.1.0)

check.structure_post_frailty_var: Check Structure of Posterior Frailty Variances

Description

The function controls that the structure of the 'Posterior Frailty Variances' coincides with the theoretical one.

Usage

check.structure_post_frailty_var(post_frailty_var, n_intervals, n_centres)

Value

An error if any condition is not satisfied.

Arguments

post_frailty_var

Posterior frailty variances S3 object of class 'PFV.AdPaik', composed of three elements:

  • 'alphaVar': posterior frailty variance for \(\alpha_j, \forall j\). It is a vector of length equal to the number of centres.

  • 'epsVar': posterior frailty variance for \(\epsilon_{jk}, \forall j,k\). It is a matrix of dimension (n_centres, n_intervals).

  • 'ZVar': posterior frailty variance for \(Z_{jk} = \alpha_j + \epsilon_{jk}, \forall j,k\). It is a matrix of dimension (n_centres, n_intervals)

n_intervals

Number of intervals of the time-domain

n_centres

Number of centres/clusters.