Evaluation of model group log-likelihood at the provided parameter vector and data. This function is internally called by 'll_AdPaik_eval' to evaluate the log-likelihood function, considering all and only the individuals belonging to a group.
ll_AdPaik_centre_eval(params, dataset, dropout_matrix, e_matrix)Group log-likelihood evaluation
Parameter vector.
Matrix of dataset regressors, with a number of rows equal to the number of individuals in a cluster.
Binary matrix indicating in which interval of the time domain and individual failed. For an individual, the sum of the row elements must be equal to 1 (if he/she failed) or 0 (if he/she does not failed). It has dimension equal to (n_individuals, n_intervals)
Matrix of dimension (n_individual, n_intervals), where each element contains the evaluation of the temporal integral, performed through the function @time_int_eval.