Function for computing the confidence interval for each posterior frailty estimates \(\hat{Z}_{jk}\).
post_frailty_CI_internal(
post_frailty_est,
post_frailty_est_var,
n_centres,
n_intervals,
level
)S3 object of class 'PFCI.AdPaik' composed of two matrices of dimension (number groups, number of intervals):
PostFrailtyCI_left: left confidence interval for each posterior frailty estimates
PostFrailtyCI_right: right confidence interval for each each posterior frailty estimates
Posterior frailty estimates list.
Posterior frailty variance list.
Number of clusters/centres.
Number of intervals of the time-domain. it is equal to the length of the tima_axis minus one.
A numeric value representing the confidence level.